ExprContainsAny class final

Inheritance
Available extensions

Constructors

ExprContainsAny({required Expr left, required Expr right})
const
ExprContainsAny.fromJson(Map<String, Object?> json)
factory
ExprContainsAny.fromProto(ExprContainsAny proto)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
left → Expr
finalinherited
op → OpBuiltin
no setteroverride
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept<R>(ExprVisitor<R> visitor) → R
override
acceptWithArg<R, A>(ExprVisitorWithArg<R, A> visitor, A arg) → R
override
access(String attr) → Expr

Available on Expr, provided by the Hierarchy extension

add(Expr rhs) → Expr

Available on Expr, provided by the Arithmetic extension

and(Expr rhs) → Expr

Available on Expr, provided by the Logical extension

collectSlots() → Set<SlotId>

Available on Expr, provided by the ExprTemplateUtils extension

Collects all slot identifiers referenced by this expression.
contains(Expr rhs) → Expr

Available on Expr, provided by the Hierarchy extension

containsAll(Expr rhs) → Expr

Available on Expr, provided by the Hierarchy extension

containsAny(Expr rhs) → Expr

Available on Expr, provided by the Hierarchy extension

equals(Expr rhs) → Expr

Available on Expr, provided by the Comparison extension

getTag(Expr tag) → Expr

Available on Expr, provided by the Hierarchy extension

greaterThan(Expr rhs) → Expr

Available on Expr, provided by the Comparison extension

greaterThanOrEquals(Expr rhs) → Expr

Available on Expr, provided by the Comparison extension

has(String attr) → Expr

Available on Expr, provided by the Hierarchy extension

hasTag(Expr tag) → Expr

Available on Expr, provided by the Hierarchy extension

ifThenElse(Expr condition, Expr thenCedarExpr, Expr elseCedarExpr) → Expr

Available on Expr, provided by the Logical extension

in_(Expr rhs) → Expr

Available on Expr, provided by the Hierarchy extension

is_(String entityType) → Expr

Available on Expr, provided by the Hierarchy extension

isIn(String entityType, Expr rhs) → Expr

Available on Expr, provided by the Hierarchy extension

isInRange(Expr rhs) → Expr

Available on Expr, provided by the IpAddressOperators extension

isIpv4() → Expr

Available on Expr, provided by the IpAddressOperators extension

isIpv6() → Expr

Available on Expr, provided by the IpAddressOperators extension

isLoopback() → Expr

Available on Expr, provided by the IpAddressOperators extension

isMulticast() → Expr

Available on Expr, provided by the IpAddressOperators extension

lessThan(Expr rhs) → Expr

Available on Expr, provided by the Comparison extension

lessThanOrEquals(Expr rhs) → Expr

Available on Expr, provided by the Comparison extension

like(CedarPattern pattern) → Expr

Available on Expr, provided by the Comparison extension

multiply(Expr rhs) → Expr

Available on Expr, provided by the Arithmetic extension

negate() → Expr

Available on Expr, provided by the Arithmetic extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
not() → Expr

Available on Expr, provided by the Logical extension

notEquals(Expr rhs) → Expr

Available on Expr, provided by the Comparison extension

or(Expr rhs) → Expr

Available on Expr, provided by the Logical extension

substituteSlots(Map<SlotId, Value> bindings) → Expr

Available on Expr, provided by the ExprTemplateUtils extension

Returns a new expression with all `ExprSlot` occurrences replaced using the provided bindings.
subtract(Expr rhs) → Expr

Available on Expr, provided by the Arithmetic extension

toJson() → Map<String, Object?>
inherited
toProto() → Expr
override
toString() → String
A string representation of this object.
override
valueToJson() → Map<String, Object?>
inherited

Operators

operator *(Expr rhs) → Expr
inherited
operator +(Expr rhs) → Expr
inherited
operator -(Expr rhs) → Expr
inherited
operator ==(Object other) → bool
The equality operator.
inherited
operator unary-() → Expr
inherited